==> kazehakase-0.1.9.tar.gz: kazehakase-0.1.9/src/mozilla/kz-mozdownloader.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2004 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __KZ_MOZ_DOWNLOADER_H__
#define __KZ_MOZ_DOWNLOADER_H__

#include <glib-object.h>
#include "kz-downloader.h"

G_BEGIN_DECLS

#define KZ_TYPE_MOZ_DOWNLOADER		 (kz_moz_downloader_get_type ())
#define KZ_MOZ_DOWNLOADER(obj)		 (G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_MOZ_DOWNLOADER, KzMozDownloader))
#define KZ_MOZ_DOWNLOADER_CLASS(klass)	 (G_TYPE_CHECK_CLASS_CAST ((klass),  KZ_TYPE_MOZ_DOWNLOADER, KzMozDownloaderClass))
#define KZ_IS_MOZ_DOWNLOADER(obj)	 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_MOZ_DOWNLOADER))
#define KZ_IS_MOZ_DOWNLOADER_CLASS(klass)(G_TYPE_CHECK_CLASS_TYPE ((klass),  KZ_TYPE_MOZ_DOWNLOADER))
#define KZ_MOZ_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj),  KZ_TYPE_MOZ_DOWNLOADER, KzMozDownloaderClass))

typedef struct _KzMozDownloader KzMozDownloader;
typedef struct _KzMozDownloaderClass KzMozDownloaderClass;
typedef struct _KzMozDownloaderPrivate KzMozDownloaderPrivate;

struct _KzMozDownloader
{
	KzDownloader parent;
	
	KzMozDownloaderPrivate *priv;
};

struct _KzMozDownloaderClass
{
	KzDownloaderClass parent_class;
};

GType            kz_moz_downloader_get_type (void);
KzMozDownloader *kz_moz_downloader_new      (gpointer aProgress,
					     const gchar *filename);

G_END_DECLS

#endif /* __KZ_MOZ_DOWNLOADER_H__ */

==> kazehakase-0.2.5.tar.gz: kazehakase-0.2.5/src/mozilla/kz-mozdownloader.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2004 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __KZ_MOZ_DOWNLOADER_H__
#define __KZ_MOZ_DOWNLOADER_H__

#include <glib-object.h>
#include "kz-downloader.h"

G_BEGIN_DECLS

#define KZ_TYPE_MOZ_DOWNLOADER		 (kz_moz_downloader_get_type ())
#define KZ_MOZ_DOWNLOADER(obj)		 (G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_MOZ_DOWNLOADER, KzMozDownloader))
#define KZ_MOZ_DOWNLOADER_CLASS(klass)	 (G_TYPE_CHECK_CLASS_CAST ((klass),  KZ_TYPE_MOZ_DOWNLOADER, KzMozDownloaderClass))
#define KZ_IS_MOZ_DOWNLOADER(obj)	 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_MOZ_DOWNLOADER))
#define KZ_IS_MOZ_DOWNLOADER_CLASS(klass)(G_TYPE_CHECK_CLASS_TYPE ((klass),  KZ_TYPE_MOZ_DOWNLOADER))
#define KZ_MOZ_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj),  KZ_TYPE_MOZ_DOWNLOADER, KzMozDownloaderClass))

typedef struct _KzMozDownloader KzMozDownloader;
typedef struct _KzMozDownloaderClass KzMozDownloaderClass;
typedef struct _KzMozDownloaderPrivate KzMozDownloaderPrivate;

struct _KzMozDownloader
{
	KzDownloader parent;
	
	KzMozDownloaderPrivate *priv;
};

struct _KzMozDownloaderClass
{
	KzDownloaderClass parent_class;
};

GType            kz_moz_downloader_get_type (void) G_GNUC_CONST;
KzMozDownloader *kz_moz_downloader_new      (gpointer aProgress,
					     const gchar *filename);

G_END_DECLS

#endif /* __KZ_MOZ_DOWNLOADER_H__ */
